import { csv, select } from 'd3';
import { scatterPlot } from './scatterPlot';   

//Adding dataset from ICE-6
const csvUrl = ['https://raw.githubusercontent.com/PY09052021/Data_Viz_ICE/main/iris.csv'  
].join('');

//reading the data
const parseRow = (d) => {
  d.sepal_length = +d.sepal_length;
  d.sepal_width = +d.sepal_width;
  d.petal_length = +d.petal_length;
  d.petal_width = +d.petal_width;
  return d;
};

//dimensions and margin for graph
const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.petal_length;
const yValue = (d) => d.petal_width;
const rxValue = (d) => d.sepal_length;
const ryValue = (d) => d.sepal_width;      
const group = (d) => d.species;

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  
  const x = xValue((d) => d.petal_width);
        
  const y = yValue((d) => d.sepal_length);
  
 //Color variable based on species
 	const color = d3.scaleOrdinal(d3.schemeCategory10);
  
  // Map with name and value
  const marks = data.map((d) => ({
          x: xValue((d) => d.petal_width),
          y: yValue((d) => d.sepal_length),
          color: color(group(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  //Scatterplot function
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.petal_width)
    .yValue((d) => d.sepal_length)
    .margin({
      top: 20,
      right: 130,
      bottom: 40,
      left: 50,
    })
    .radius(5);
  //Creating legends
    const info = svg.selectAll('info')
      .data(color.domain())
      .enter().append('g')
      .attr('class', 'info')
      .attr('transform', function(d,i){ return 'translate(0,' + i * 20 + ')'; });
//appending legends
    info.append("rect")
  			.attr('x', width-20)
     	 .attr('width', 18)
     	 .attr('height', 18)
     	 .style('fill', color);

    info.append('text')
    .attr('x', width - 26)
    .attr('y', 9)
    .attr('dy', '.35em')
    .style('text-anchor', 'end')
    .attr("font-family", "Arial, Helvetica, sans-serif")
    .text(function(d){ return d; });
	
  svg.append('text')
			.attr('x', 50)
			.attr('y', 20)
			.attr('class', 'label')
			.text('Sepal Width');


		svg.append('text')
			.attr('x', width)
			.attr('y', height - 50)
			.attr('text-anchor', 'end')
			.attr('class', 'label')
			.text('Sepal Length');
		
  //Updating circle with map parameter
  svg.selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
  const columns = [
    'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length',
  ];
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);
    svg.call(plot);
    i++;
  }, 2000);
};
main();
